==> org.eclipse.scout.rt.client.mobile.source_3.9.2.20131003-1323.jar: org/eclipse/scout/rt/client/mobile/ui/form/AbstractFormActionFetcher.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.client.mobile.ui.form;

import java.util.List;

import org.eclipse.scout.rt.client.mobile.ui.action.ActionButtonBarUtility;
import org.eclipse.scout.rt.client.ui.action.menu.IMenu;
import org.eclipse.scout.rt.client.ui.form.IForm;
import org.eclipse.scout.rt.client.ui.form.fields.button.IButton;

public abstract class AbstractFormActionFetcher implements IActionFetcher {
  private IForm m_form;

  public AbstractFormActionFetcher(IForm form) {
    m_form = form;
  }

  public IForm getForm() {
    return m_form;
  }

  @Override
  public abstract List<IMenu> fetch();

  protected List<IMobileAction> convertCustomProcessButtons() {
    IButton[] customProcessButtons = getForm().getRootGroupBox().getCustomProcessButtons();
    if (customProcessButtons == null || customProcessButtons.length == 0) {
      return null;
    }

    return ActionButtonBarUtility.convertButtonsToActions(getForm().getRootGroupBox().getCustomProcessButtons());
  }

}

==> org.eclipse.scout.rt.client.mobile.source_5.0.0.20150427-0754.jar: org/eclipse/scout/rt/client/mobile/ui/form/AbstractFormActionFetcher.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.client.mobile.ui.form;

import java.util.List;

import org.eclipse.scout.commons.CollectionUtility;
import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.rt.client.mobile.ui.action.ActionButtonBarUtility;
import org.eclipse.scout.rt.client.ui.form.IForm;
import org.eclipse.scout.rt.client.ui.form.fields.button.IButton;

public abstract class AbstractFormActionFetcher implements IActionFetcher {
  private IForm m_form;

  public AbstractFormActionFetcher(IForm form) {
    m_form = form;
  }

  public IForm getForm() {
    return m_form;
  }

  protected List<IMobileAction> convertCustomProcessButtons() throws ProcessingException {
    List<IButton> customProcessButtons = getForm().getRootGroupBox().getCustomProcessButtons();

    if (CollectionUtility.hasElements(customProcessButtons)) {
      return ActionButtonBarUtility.convertButtonsToActions(getForm().getRootGroupBox().getCustomProcessButtons());
    }
    else {
      return CollectionUtility.emptyArrayList();
    }
  }
}
